==> freecad_0.11.4446-dfsg.orig.tar.gz: FreeCAD-0.11.4446/src/Mod/Drawing/Gui/Resources/translations/Drawing_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS>
  <context>
    <name>CmdDrawingExportPage</name>
    <message>
      <location/>
      <source>File</source>
      <translation>Datoteka</translation>
    </message>
    <message>
      <location/>
      <source>&amp;Export page...</source>
      <translation>Izvedi stranicu...</translation>
    </message>
    <message>
      <location/>
      <source>Export a page to an SVG file</source>
      <translation>Izvoz stranicu za SVG datoteku</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingNewA3Landscape</name>
    <message>
      <location/>
      <source>Drawing</source>
      <translation>Crtanje</translation>
    </message>
    <message>
      <location/>
      <source>Insert new A3 landscape drawing</source>
      <translation>Umetanje novog A3 pejzaža za crtanje</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingNewView</name>
    <message>
      <location/>
      <source>Drawing</source>
      <translation>Crtanje</translation>
    </message>
    <message>
      <location/>
      <source>Insert a new View in the active drawing</source>
      <translation>Umetnite novi pogled u aktivnom crtežu</translation>
    </message>
    <message>
      <location/>
      <source>Insert view in drawing</source>
      <translation>Umetnite pogled u crtežu</translation>
    </message>
    <message>
      <location/>
      <source>Insert a new View of a Part in the active drawing</source>
      <translation>Umetnite novi pogled na dio u aktivnom crtežu</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingOpen</name>
    <message>
      <location/>
      <source>Drawing</source>
      <translation>Crtanje</translation>
    </message>
    <message>
      <location/>
      <source>Open SVG...</source>
      <translation>Otvori SVG ...</translation>
    </message>
    <message>
      <location/>
      <source>Open a scalable vector graphic</source>
      <translation>Otvorite ljestivcu- vektorska grafika</translation>
    </message>
  </context>
  <context>
    <name>DrawingGui::DrawingView</name>
    <message>
      <location/>
      <source>&amp;Background</source>
      <translation>I pozadina</translation>
    </message>
    <message>
      <location/>
      <source>&amp;Outline</source>
      <translation>&amp;amp; Potez</translation>
    </message>
    <message>
      <location/>
      <source>&amp;Native</source>
      <translation>&amp;amp; Prirodan</translation>
    </message>
    <message>
      <location/>
      <source>&amp;OpenGL</source>
      <translation>I OpenGL</translation>
    </message>
    <message>
      <location/>
      <source>&amp;Image</source>
      <translation>I slike</translation>
    </message>
    <message>
      <location/>
      <source>&amp;High Quality Antialiasing</source>
      <translation>&amp;amp; visko kvalitetno anti prekrivanje</translation>
    </message>
    <message>
      <location/>
      <source>Open SVG File</source>
      <translation>Otvori SVG datoteku</translation>
    </message>
    <message>
      <location/>
      <source>Could not open file '%1'.</source>
      <translation>Nije moguće otvoriti datoteku '%1.</translation>
    </message>
    <message>
      <location/>
      <source>&amp;Renderer</source>
      <translation>&amp;; Renderer</translation>
    </message>
    <message>
      <location/>
      <source>Export PDF</source>
      <translation>Izvoz PDF</translation>
    </message>
    <message>
      <location/>
      <source>PDF file (*.pdf)</source>
      <translation>PDF datoteke (*. pdf)</translation>
    </message>
  </context>
  <context>
    <name>DrawingGui::Workbench</name>
    <message>
      <location/>
      <source>Drawing</source>
      <translation>Crtanje</translation>
    </message>
    <message>
      <location/>
      <source>I/O</source>
      <translation>I / O</translation>
    </message>
    <message>
      <location/>
      <source>Drawing types</source>
      <translation>Vrste crtanja</translation>
    </message>
    <message>
      <location/>
      <source>Views</source>
      <translation>Pogledi</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location/>
      <source>Choose an SVG file to open</source>
      <translation>Odaberite SVG datoteku za otvaranje</translation>
    </message>
    <message>
      <location/>
      <source>Drawing viewer</source>
      <translation>Preglednik za crtanje</translation>
    </message>
    <message>
      <location/>
      <source>Scalable Vector Graphics (*.svg *.svgz)</source>
      <translation>Ljestvica- Vector Graphics (SVG *. *. svgz)</translation>
    </message>
    <message>
      <location/>
      <source>Wrong selection</source>
      <translation>Pogrešan odabir</translation>
    </message>
    <message>
      <location/>
      <source>Select a Part object.</source>
      <translation>Odaberite dio objekta.</translation>
    </message>
    <message>
      <location/>
      <source>No page to insert</source>
      <translation>Nema stranica za umetanje</translation>
    </message>
    <message>
      <location/>
      <source>Create a page to insert.</source>
      <translation>Stvaranje stranica za umetanje.</translation>
    </message>
    <message>
      <location/>
      <source>Select one Page object.</source>
      <translation>Odaberite jednu stranicu objekta</translation>
    </message>
    <message>
      <location/>
      <source>SVG(*.svg)</source>
      <translation>SVG (*. svg)</translation>
    </message>
    <message>
      <location/>
      <source>All Files (*.*)</source>
      <translation>Sve datoteke (*.*)</translation>
    </message>
    <message>
      <location/>
      <source>Export page</source>
      <translation>Izvedi stranicu</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location/>
      <source>Drawing</source>
      <translation>Crtanje</translation>
    </message>
    <message>
      <location/>
      <source>I/O</source>
      <translation>I / O</translation>
    </message>
    <message>
      <location/>
      <source>Drawing types</source>
      <translation>Vrste crtanja</translation>
    </message>
    <message>
      <location/>
      <source>Views</source>
      <translation>Pogledi</translation>
    </message>
  </context>
</TS>

==> freecad_0.12.5284-dfsg.orig.tar.gz: FreeCAD-0.12.5284/src/Mod/Drawing/Gui/Resources/translations/Drawing_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS>
  <context>
    <name>CmdDrawingExportPage</name>
    <message>
      <location filename="../../Command.cpp" line="+285"/>
      <source>File</source>
      <translation>Datoteka</translation>
    </message>
    <message>
      <source>&amp;Export page...</source>
      <translation>Izvedi stranicu...</translation>
    </message>
    <message>
      <source>Export a page to an SVG file</source>
      <translation>Izvoz stranicu za SVG datoteku</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingNewA3Landscape</name>
    <message>
      <source>Drawing</source>
      <translation>Crtanje</translation>
    </message>
    <message>
      <source>Insert new A3 landscape drawing</source>
      <translation>Umetanje novog A3 pejzaža za crtanje</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingNewPage</name>
    <message>
      <source>Drawing</source>
      <translation>Crtanje</translation>
    </message>
    <message>
      <source>Insert new drawing</source>
      <translation>Umetni novi crtež</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingNewView</name>
    <message>
      <source>Drawing</source>
      <translation>Crtanje</translation>
    </message>
    <message>
      <source>Insert view in drawing</source>
      <translation>Umetnite pogled u crtežu</translation>
    </message>
    <message>
      <source>Insert a new View of a Part in the active drawing</source>
      <translation>Umetnite novi pogled na dio u aktivnom crtežu</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingOpen</name>
    <message>
      <source>Drawing</source>
      <translation>Crtanje</translation>
    </message>
    <message>
      <source>Open SVG...</source>
      <translation>Otvori SVG ...</translation>
    </message>
    <message>
      <source>Open a scalable vector graphic</source>
      <translation>Otvorite ljestivcu- vektorska grafika</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingProjectShape</name>
    <message>
      <source>Drawing</source>
      <translation>Crtanje</translation>
    </message>
    <message>
      <source>Project shape...</source>
      <translation>Projecirani oblik ...</translation>
    </message>
    <message>
      <source>Project shape onto a user-defined plane</source>
      <translation>Projeciraj oblik na korisnički definiranu ravninu</translation>
    </message>
  </context>
  <context>
    <name>DrawingGui::DrawingView</name>
    <message>
      <location filename="../../DrawingView.cpp" line="+206"/>
      <source>&amp;Background</source>
      <translation>I pozadina</translation>
    </message>
    <message>
      <source>&amp;Outline</source>
      <translation>&amp;amp; Potez</translation>
    </message>
    <message>
      <source>&amp;Native</source>
      <translation>&amp;amp; Prirodan</translation>
    </message>
    <message>
      <source>&amp;OpenGL</source>
      <translation>I OpenGL</translation>
    </message>
    <message>
      <source>&amp;Image</source>
      <translation>I slike</translation>
    </message>
    <message>
      <source>&amp;High Quality Antialiasing</source>
      <translation>&amp;amp; visko kvalitetno anti prekrivanje</translation>
    </message>
    <message>
      <source>Open SVG File</source>
      <translation>Otvori SVG datoteku</translation>
    </message>
    <message>
      <source>Could not open file '%1'.</source>
      <translation>Nije moguće otvoriti datoteku '%1.</translation>
    </message>
    <message>
      <source>&amp;Renderer</source>
      <translation>&amp;; Renderer</translation>
    </message>
    <message>
      <source>Export PDF</source>
      <translation>Izvoz PDF</translation>
    </message>
    <message>
      <source>PDF file (*.pdf)</source>
      <translation>PDF datoteke (*. pdf)</translation>
    </message>
    <message>
      <source>Page sizes</source>
      <translation>Veličine stranica</translation>
    </message>
    <message>
      <source>A0</source>
      <translation>A0</translation>
    </message>
    <message>
      <source>A1</source>
      <translation>A1</translation>
    </message>
    <message>
      <source>A2</source>
      <translation>A2</translation>
    </message>
    <message>
      <source>A3</source>
      <translation>A3</translation>
    </message>
    <message>
      <source>A4</source>
      <translation>A4</translation>
    </message>
    <message>
      <source>A5</source>
      <translation>A5</translation>
    </message>
  </context>
  <context>
    <name>DrawingGui::TaskProjection</name>
    <message>
      <location filename="../../TaskDialog.cpp" line="+49"/>
      <source>Visible sharp edges</source>
      <translation>Vidljivi oštri rubovi</translation>
    </message>
    <message>
      <source>Visible smooth edges</source>
      <translation>Vidljivi glatki rubovi</translation>
    </message>
    <message>
      <source>Visible sewn edges</source>
      <translation>Vidljivi iscrtkani rubovi</translation>
    </message>
    <message>
      <source>Visible outline edges</source>
      <translation>Vidljivi vanjski rubovi</translation>
    </message>
    <message>
      <source>Visible isoparameters</source>
      <translation>Vidljivi izometrijski parametri</translation>
    </message>
    <message>
      <source>Hidden sharp edges</source>
      <translation>Skriveni oštri rubovi</translation>
    </message>
    <message>
      <source>Hidden smooth edges</source>
      <translation>Skriveni glatki rubovi</translation>
    </message>
    <message>
      <source>Hidden sewn edges</source>
      <translation>Skriveni iscrtkani rubovi</translation>
    </message>
    <message>
      <source>Hidden outline edges</source>
      <translation>Skriveni vanjski rubovi</translation>
    </message>
    <message>
      <source>Hidden isoparameters</source>
      <translation>Skriveni izometrijski parametri</translation>
    </message>
    <message>
      <source>Project shapes</source>
      <translation>Projecirani oblik</translation>
    </message>
  </context>
  <context>
    <name>Drawing_NewPage</name>
    <message>
      <location filename="../../Command.cpp" line="-196"/>
      <source>A0 landscape</source>
      <translation>A0 pejzaž</translation>
    </message>
    <message>
      <source>Insert new A0 landscape drawing</source>
      <translation>Umetnite novi A0 pejzažni crtež</translation>
    </message>
    <message>
      <source>A1 landscape</source>
      <translation>A1 pejzaž</translation>
    </message>
    <message>
      <source>Insert new A1 landscape drawing</source>
      <translation>Umetnite novi A1 pejzažni crtež</translation>
    </message>
    <message>
      <source>A2 landscape</source>
      <translation>A2 pejzaž</translation>
    </message>
    <message>
      <source>Insert new A2 landscape drawing</source>
      <translation>Umetnite novi A2 pejzažni crtež</translation>
    </message>
    <message>
      <source>A3 landscape</source>
      <translation>A3 pejzaž</translation>
    </message>
    <message>
      <source>Insert new A3 landscape drawing</source>
      <translation>Umetanje novog A3 pejzaža za crtanje</translation>
    </message>
    <message>
      <source>A4 landscape</source>
      <translation>A4 pejzaž</translation>
    </message>
    <message>
      <source>Insert new A4 landscape drawing</source>
      <translation>Umetnite novi A4 pejzažni crtež</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>Choose an SVG file to open</source>
      <translation>Odaberite SVG datoteku za otvaranje</translation>
    </message>
    <message>
      <location filename="../../AppDrawingGuiPy.cpp" line="+61"/>
      <source>Drawing viewer</source>
      <translation>Preglednik za crtanje</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="+1"/>
      <source>Scalable Vector Graphics (*.svg *.svgz)</source>
      <translation>Ljestvica- Vector Graphics (SVG *. *. svgz)</translation>
    </message>
    <message>
      <source>Wrong selection</source>
      <translation>Pogrešan odabir</translation>
    </message>
    <message>
      <source>Select a Part object.</source>
      <translation>Odaberite dio objekta.</translation>
    </message>
    <message>
      <source>No page to insert</source>
      <translation>Nema stranica za umetanje</translation>
    </message>
    <message>
      <source>Create a page to insert.</source>
      <translation>Stvaranje stranica za umetanje.</translation>
    </message>
    <message>
      <source>Select one Page object.</source>
      <translation>Odaberite jednu stranicu objekta</translation>
    </message>
    <message>
      <source>SVG(*.svg)</source>
      <translation>SVG (*. svg)</translation>
    </message>
    <message>
      <source>All Files (*.*)</source>
      <translation>Sve datoteke (*.*)</translation>
    </message>
    <message>
      <source>Export page</source>
      <translation>Izvedi stranicu</translation>
    </message>
    <message>
      <location filename="../../ViewProviderPage.cpp" line="-25"/>
      <source>Show drawing</source>
      <translation>Prikaži crtež</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+37"/>
      <source>Drawing</source>
      <translation>Crtanje</translation>
    </message>
  </context>
</TS>
